/******************************************************************************
*
* main.c - implementation of "Panasonic Control Program" client C entry and
*          interrupt handling, derived from "Microstamp11 GNU-C Runtime"
*
* Copyright (c) 2002, 2004, Don Woodward.
*
*
* This file is part of "Panasonic Control Program".
*
* "Panasonic Control Program" is free software; you can redistribute
* it and/or modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation; either version 2 of the
* License, or any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*
******************************************************************************/

#include "microstamp11.h"
#include "shell.h"
#include "hc11ed0.h"
#include "panny.h"
#include "sonyIR.h"

/******************************************************************************
* main.c forward declarations
******************************************************************************/

/******************************************************************************
* main.c exported functions
******************************************************************************/
/* main()   */
int
main(int argc, char ** argv)
{
    SonyIR_Reset();

    // enable interrupts now that hw init is complete
    enable();
        
    /* fire up the shell */
    Shell();

    for (;;);

    return 0;
}

/* int_notify()   */
void
int_notify(u8 nInterrupt)
{
    /* int_notify() is the entry point for client interrupt handling.
       nInterrupt is set to the interrupt id of the interrupt being
       notified.  The interrupt ids are defined in microstamp11.h */

    switch (nInterrupt)
    {
        case INT_RTI:
            SonyIR_OnRealTimeInterrupt();
            PannyOnRealTimeInterrupt();
            break;
        case INT_TIC1:
            TFLG1 = IC1F;   // clear the TIC1 flag
            SonyIR_OnTimerInputCaptureInterrupt();
            break;
        default:
            break;
    }
}


/* on_idle() */
void
on_idle()
{
    SonyIR_OnIdle();
}

/******************************************************************************
*   LOG
*******************************************************************************
*   03-Jan-02   dwoodward   created
*
*/
