/******************************************************************************
*
* microstamp11.h - interface of microstamp11 specific implementation of
*                  the "Panasonic Control Program".
*
* Copyright (c) 2002, 2004, Don Woodward.
*
*
* This file is part of "Panasonic Control Program" and was derived
* from "MicroStamp11 GNU-C runtime".
*
* "Panasonic Control Program" is free software; you can redistribute
* it and/or modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation; either version 2 of the
* License, or any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*
******************************************************************************/

#ifndef _MICROSTAMP11_MICROSTAMP11_H_
#define _MICROSTAMP11_MICROSTAMP11_H_
#ifndef _MICROSTAMP11_ASSEMBLY_

/******************************************************************************
*  First come C declarations
******************************************************************************/

/******************************************************************************
*  #defines, typedefs, and structs
******************************************************************************/
/* #defines */
#define TRUE            (1)
#define FALSE           (0)
#define NULL            (0)

/* typedefs */
typedef unsigned char   u8;
typedef unsigned short  u16;
typedef unsigned long   u32;
typedef signed   char   s8;
typedef signed   short  s16;
typedef signed   long   s32;
typedef u8              boolean;

/* structs */
typedef struct _TimeStruct
{
    u32 m_nSeconds;
    u16 m_nMilliseconds;
} TimeStruct;

/******************************************************************************
*  PUBLIC FUNCTIONS
******************************************************************************/
/* public inline functions                                  */
static __inline__ void disable()   { asm("sei"); }                      /* ISSUE: These don't nest */
static __inline__ void enable()    { asm("cli"); }

/* public functions implemented in microstamp11.c           */
void        serialFlushInput();                                         /* flushes the serial port input, dropping pending character if there is one */
u8          serialGetChar();                                            /* blocks until char received; returns char from serial port    */
void        serialPutChar(u8 c);                                        /* puts character to serial port (xlates \n to \r\n)            */
boolean     serialCharPending();                                        /* non-zero if input character pending on serial port           */
void        serialPutString(const char * pString);                      /* Puts a string to the serial port                             */
void        serialPutLine(const char * pLine);                          /* Puts a string to the serial port with a newline added        */
void        serialGetLine(char * pBuff, u16 nBuffLen, boolean bEcho);   /* Blocks until a full line is received on the serial port, echoing out if bEcho is TRUE */
void        getKernelTime(TimeStruct * pTimeStructToSet);               /* fills pTimeStructToSet with the kernel time */
void        getMaxStack(u16 * pMaxStackToSet);                          /* fills pMaxStackToSet with the max (lowest) observed stack pointer value */
void        sleep(u32 nMilliseconds);                                   /* sleeps for nMilliseconds */

/* extern functions - implemented in client code            */
extern void int_notify(u8 nInterrupt);
extern void init_globals();
extern void on_idle();

/******************************************************************************
*  Now come C and ASSEMBLY declarations
******************************************************************************/
#endif                                      /* #ifndef _MICROSTAMP11_ASSEMBLY_ */

/* #defines for interrupts. 
   These are the values passed as nInterrupt into the client's int_notify function */
#define INT_SCI			1
#define INT_SPI			2
#define INT_PAI			3
#define INT_PAO			4
#define INT_TOF			5
#define INT_TOC5		6
#define INT_TOC4		7
#define INT_TOC3		8
#define INT_TOC2		9
#define INT_TOC1		10
#define INT_TIC3		11
#define INT_TIC2		12
#define INT_TIC1		13
#define INT_RTI			14
#define INT_IRQ			15
#define INT_XIRQ		16
#define INT_SWI			17
#define INT_TRAP		18
#define INT_COP_FAIL	19
#define INT_COP_CMF		20

#endif /* _MICROSTAMP11_MICROSTAMP11_H_ */

/******************************************************************************
*   LOG
*******************************************************************************
*   03-Jan-02   dwoodward   created
*
*/
