;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; microstampGnu.s - microstamp11 board initialization for "Panasonic Control Program"
;				  - works on all Microstamp11 variants - 
;				  - edit memory.x for board specific configuration
;				  - and do not put any board specific dependencies in this file!!!
;
;
; Copyright (c) 2002, 2004, Don Woodward.
;
;
; This file is part of "Panasonic Control Program" and was derived
; from "MicroStamp11 GNU-C runtime".
;
; "Panasonic Control Program" is free software; you can redistribute
; it and/or modify it under the terms of the GNU General Public License
; as published by the Free Software Foundation; either version 2 of the
; License, or any later version.
;
; This program is distributed in the hope that it will be useful,
; but WITHOUT ANY WARRANTY; without even the implied warranty of
; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
; GNU General Public License for more details.
;
; You should have received a copy of the GNU General Public License
; along with this program; if not, write to the Free Software
; Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; microstampGnu.s - NOTE TO YOU THE PROGRAMMER
;				  - Modify this file to your hearts content.  If you make an
;				  - improvement, email it to Don Woodward with a readme
;				  - file and I will incorporate it into the official source.
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; microstampGnu.s - #includes
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
#define _MICROSTAMP11_ASSEMBLY_
#include "hc11ed0.h"                /* get register config info (REG_BASE) */
#include "microstamp11.h"           /* get symbolic interrupt constants */
#undef _MICROSTAMP11_ASSEMBLY_

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; microstampGnu.s - constants
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
.set    tflg2,      REG_BASE+0x25	;timer interrupt flag register 2

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; microstampGnu.s -	_microstamp11Start - what the reset vector points to!
;				  - _microstamp11Start performs microstamp 11 hardware and [our]
;                 - runtime initialization.  It then jumps to _start so gnu can
;                 - perform C runtime initialization and eventually call your
;                 - function main.
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

.sect .text		  ; always explicitly identify code as belonging to .sect .text

_microstamp11Start:

            sei                                 ; disable interrrupts
            bra     _start                      ; let gnu start

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; microstampGnu.s -	INTERRUPT FUNCTIONS
;				  - Each discrete interrupt function loads accumulator b with
;				  - the interrupt level and then branches to _interruptDispatch
;                 - which pushes gnu soft registers, calls client int_notify
;                 - (accumulator b is arg to function) and then restores soft
;                 - registers
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

.sect .text		  ; always explicitly identify code as belonging to .sect .text

_interruptDispatch:
            ldx     _.frame                    ; push all gnu soft registers on the stack
            pshx
            ldx     _.tmp
            pshx
            ldx     _.d1
            pshx
            ldx     _.d2
            pshx
            ldx     _.d3
            pshx
            ldx     _.d4
            pshx
            ldx     _.xy
            pshx
            ldx     _.z
            pshx

            stab    _.d1
            jsr     _microstamp11_check_stack   ; now that we have saved gnus soft registers
                                                ; quick remember the stacks highest (lowest address)
                                                ; value as an aid to detecting stack overflows
            ldab    _.d1                        ; make sure that _microstamp11_check_stack does not use _.d1 !!

_sciCheck:
            cmpb    #INT_SCI                    ; we handle the serial interrupt ourselves
            bne     _rtiCheck                   ; 
            jsr     _microstamp11_handle_sci 
            bra     _interruptDispatchComplete  ; and do not give the client a chance at it
_rtiCheck:
            cmpb    #INT_RTI                    ; we also handle the real time interrupt
            bne     _interruptDispatchToClient
            ldaa	#0x40
	        staa	tflg2                       ; by first clearing real-time interrupt flag
            jsr     _microstamp11_handle_rti    ; then doing our own c-handling of the interrupt
            ldab    #INT_RTI                    ; and falling through to the int_notify call to give
                                                ; the client a chance at it also
_interruptDispatchToClient:
			jsr		int_notify                  ; now we can jsr to c code to handle the interrupt
                                                ; _microstamp11_int_notify takes a u8 arg which gnu
                                                ; uses accumulator b for
_interruptDispatchComplete:
            pulx                               ; restore the gnu soft registers
            stx     _.z
            pulx
            stx     _.xy
            pulx
            stx     _.d4
            pulx
            stx     _.d3
            pulx
            stx     _.d2
            pulx
            stx     _.d1
            pulx
            stx     _.tmp
            pulx
            stx     _.frame

_nullint:
			rti                                ; safe to rti

_interruptSCI:
			ldab	#INT_SCI
			bra		_interruptDispatch;
_interruptSPI:
			ldab	#INT_SPI
			bra		_interruptDispatch;
_interruptPAI:
			ldab	#INT_PAI
			bra		_interruptDispatch;
_interruptPAO:
			ldab	#INT_PAO
			bra		_interruptDispatch;
_interruptTOF:
			ldab	#INT_TOF
			bra		_interruptDispatch;
_interruptTOC5:
			ldab	#INT_TOC5
			bra		_interruptDispatch;
_interruptTOC4:
			ldab	#INT_TOC4
			bra		_interruptDispatch;
_interruptTOC3:
			ldab	#INT_TOC3
			bra		_interruptDispatch;
_interruptTOC2:
			ldab	#INT_TOC2
			bra		_interruptDispatch;
_interruptTOC1:
			ldab	#INT_TOC1
			bra		_interruptDispatch;
_interruptTIC3:
			ldab	#INT_TIC3
			bra		_interruptDispatch;
_interruptTIC2:
			ldab	#INT_TIC2
			bra		_interruptDispatch;
_interruptTIC1:
			ldab	#INT_TIC1
			bra		_interruptDispatch;
_interruptRTI:
			ldab	#INT_RTI
			bra		_interruptDispatch;
_interruptIRQ:
			ldab	#INT_IRQ
			bra		_interruptDispatch;
_interruptXIRQ:
			ldab	#INT_XIRQ
			bra		_interruptDispatch;
_interruptSWI:
			ldab	#INT_SWI
			bra		_interruptDispatch;
_interruptTRAP:
			ldab	#INT_TRAP
			bra		_interruptDispatch;
_interruptCOP_FAIL:
			ldab	#INT_COP_FAIL
			bra		_interruptDispatch;
_interruptCOP_CMF:
			ldab	#INT_COP_CMF
			bra		_interruptDispatch;

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; microstampGnu.s -	INTERRUPT VECTORS
;				  NOTE: The ms11demo.asm sample program starts the vectors
;                 - at 0xFFD6, but gnu wants them at 0xFFC0.  This location gnu
;                 - defaults to can be overrided either by specifying an explicit
;                 - location for the section .vectors on the link command line,
;                 - or by creating a complicated board script file and installing
;                 - it into the gnu distrubution.  We dont do this because
;                 - we dont need to, its a pain, and I want to be able to install
;                 - gnew versions of gnu on a whim without having to worry about
;                 - reconfiguration.  I leave out the link line enhancement because
;                 - it requires an extra command line option and starting the vector
;                 - table early doesnt hurt until my code wants to grow there.
;
;                 NOTE: gnu wants the reset vector to point to the global
;                 - symbol _start which lives in crt0.o which you magically get
;                 - to always link against whether you like it or not unless you
;                 - explicitly provide your own crt0.o.  Rather than fight the
;                 - system, well provide our own reset vector which well use to explicitly
;                 - disable interrupts and then branch to gnus _start function.
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

	.sect .vectors              ; internally generated gnu section name (do not change)
	.globl vectors              ; mark it as globl to force the inclusion of the table

vectors:
	.word   _nullint				; 0xFFc0 - dummy
	.word   _nullint				; 0xFFc2 - dummy
	.word   _nullint				; 0xFFc4 - dummy
	.word   _nullint				; 0xFFc6 - dummy
	.word   _nullint				; 0xFFc8 - dummy
	.word   _nullint				; 0xFFca - dummy
	.word   _nullint				; 0xFFcc - dummy
	.word   _nullint				; 0xFFce - dummy
	.word   _nullint				; 0xFFd0 - dummy
	.word   _nullint				; 0xFFd2 - dummy
	.word   _nullint				; 0xFFd4 - dummy

	.word   _interruptSCI		    ; 0xFFd6 - SCI
	.word   _interruptSPI		    ; 0xFFd8 - SPI
	.word   _interruptPAI		    ; 0xFFda - PAII
	.word   _interruptPAO		    ; 0xFFdc - PAOVI
	.word   _interruptTOF		    ; 0xFFde - TOI
	.word   _interruptTOC5		    ; 0xFFe0 - TOC5
	.word   _interruptTOC4		    ; 0xFFe2 - TOC4
	.word   _interruptTOC3		    ; 0xFFe4 - TOC3
	.word   _interruptTOC2		    ; 0xFFe6 - TOC2
	.word   _interruptTOC1		    ; 0xFFe8 - TOC1
	.word   _interruptTIC3		    ; 0xFFea - TIC3
	.word   _interruptTIC2		    ; 0xFFec - TIC2
	.word   _interruptTIC1		    ; 0xFFee - TIC1
	.word   _interruptRTI		    ; 0xFFf0 - RTII
	.word   _interruptIRQ		    ; 0xFFf2 - IRQ
	.word   _interruptXIRQ		    ; 0xFFf4 - XIRQ
	.word   _interruptSWI		    ; 0xFFf6 - SWI
	.word   _interruptTRAP		    ; 0xFFf8 - ILL
	.word   _interruptCOP_FAIL	    ; 0xFFfa - COP Failure
	.word   _interruptCOP_CMF	    ; 0xFFfc - COP Clock monitor
	.word   _microstamp11Start	    ; 0xFFfe - reset

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;   LOG
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;   03-Jan-02   dwoodward   created
;

