/******************************************************************************
*
* panny.h - interface of microstamp11 panny serial control (Panasonic TH50PH-D3)
*           for "Panasonic Control Program"
*
* Copyright (c) 2002, 2004, Don Woodward.
*
*
* This file is part of "Panasonic Control Program".
*
* "Panasonic Control Program" is free software; you can redistribute
* it and/or modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation; either version 2 of the
* License, or any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*
******************************************************************************/

#ifndef _MICROSTAMP11_PANNY_H_
#define _MICROSTAMP11_PANNY_H_

/******************************************************************************
*  PUBLIC types
******************************************************************************/
typedef enum _PannyCommandID
{
    kCmdPanny_POWER_ON = 0,
    kCmdPanny_POWER_OFF,
    kCmdPanny_VOL_UP,
    kCmdPanny_VOL_DOWN,
    kCmdPanny_VOL_MUTE,
    kCmdPanny_INPUT_VIDEO,
    kCmdPanny_INPUT_COMPONENT,
    kCmdPanny_INPUT_VGA_PC,
    kCmdPanny_ASPECT_4x3,
    kCmdPanny_ASPECT_ZOOM,
    kCmdPanny_ASPECT_FULL,
    kCmdPanny_ASPECT_JUST,
    kCmdPanny_ASPECT_AUTO,
} PannyCommandID;

typedef enum _PannyMacroID
{
    kMacroPanny_ON_VGA_FULL = 0,     /* ON, INPUT VGA, FULL ASPECT */
    kMacroPanny_ON_COMPONENT_FULL,   /* ON, INPUT COMPONENT, FULL ASPECT */
    kMacroPanny_ON_VIDEO_AUTO,       /* ON, INPUT VIDEO, AUTO ASPECT */
    kMacroPanny_OFF                  /* OFF, for convenience */
} PannyMacroID;

/******************************************************************************
*  PUBLIC FUNCTIONS
******************************************************************************/
void PannyOnRealTimeInterrupt();
boolean DispatchPannyCommand(PannyCommandID commandID);     /* dispatches a discrete command */
boolean ExecutePannyMacro(PannyMacroID macroID);            /* executes a sequence of commands */
void PannyNotifyIRCodeReceived(u16 nIRCode);                /* notifies that an IR code has been received */

#endif /* #ifndef _MICROSTAMP11_PANNY_H_ */

/******************************************************************************
*   LOG
*******************************************************************************
*   27-Jan-02   dwoodward   created
*
*/
