/******************************************************************************
*
* sonyIR.h - interface of microstamp11 sonyIR decode for "Panasonic Control Program"
*
* Copyright (c) 2002, 2004, Don Woodward.
*
*
* This file is part of "Panasonic Control Program".
*
* "Panasonic Control Program" is free software; you can redistribute
* it and/or modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation; either version 2 of the
* License, or any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*
******************************************************************************/

#ifndef _MICROSTAMP11_SONYIR_H_
#define _MICROSTAMP11_SONYIR_H_

/******************************************************************************
*  PUBLIC types and #defines
******************************************************************************/
typedef u16 SonyIRCode;
typedef u8  SonyIRDevice;
typedef u8  SonyIRKey;

/* Macros to translate device and key into ir code and vice versa */
#define SONYMAKEIRCODE(device, key) (((SonyIRCode)((key << 5) | device)))
#define SONYIRCODETODEVICE(irCode)  (((SonyIRDevice)(irCode & 0x1F)))
#define SONYIRCODETOKEY(irCode)     (((SonyIRKey)(irCode >> 5)))

/* SONY DEVICE CODES */
#define SONY_IRD_CD                 ((SonyIRDevice)0x11)
#define SONY_IRD_TV                 ((SonyIRDevice)0x10)
#define SONY_IRD_VCR1               ((SonyIRDevice)0x08)
#define SONY_IRD_VCR2               ((SonyIRDevice)0x1C)
#define SONY_IRD_VCR3               ((SonyIRDevice)0x1A)
#define SONY_IRD_LASERDISC          ((SonyIRDevice)0x0C)

/* SONY KEY CODES COMMON TO ALL SONY DEVICES */
#define SONY_IRK_POWER              ((SonyIRKey)0x54)
#define SONY_IRK_1                  ((SonyIRKey)0x00)
#define SONY_IRK_2                  ((SonyIRKey)0x40)
#define SONY_IRK_3                  ((SonyIRKey)0x20)
#define SONY_IRK_4                  ((SonyIRKey)0x60)
#define SONY_IRK_5                  ((SonyIRKey)0x10)
#define SONY_IRK_6                  ((SonyIRKey)0x50)
#define SONY_IRK_7                  ((SonyIRKey)0x30)
#define SONY_IRK_8                  ((SonyIRKey)0x70)
#define SONY_IRK_9                  ((SonyIRKey)0x08)
#define SONY_IRK_0                  ((SonyIRKey)0x48)
#define SONY_IRK_ENTER              ((SonyIRKey)0x68)
#define SONY_IRK_CHANNELUP          ((SonyIRKey)0x04)
#define SONY_IRK_CHANNELDOWN        ((SonyIRKey)0x44)

/* SONY KEY CODES UNIQUE TO SONY TVs */
#define SONY_IRK_TVMUTE             ((SonyIRKey)0x14)
#define SONY_IRK_TVSLEEP            ((SonyIRKey)0x36)
#define SONY_IRK_TVCLEAR            ((SonyIRKey)0x16)
#define SONY_IRK_TVTIMERBLOCK       ((SonyIRKey)0x06)
#define SONY_IRK_TVRESET            ((SonyIRKey)0x34)
#define SONY_IRK_TVSELECT           ((SonyIRKey)0x1F)
#define SONY_IRK_TVOFFREPEAT        ((SonyIRKey)0x1E)
#define SONY_IRK_TVAMPM             ((SonyIRKey)0x66)
#define SONY_IRK_TVLEVELDOWN        ((SonyIRKey)0x57)
#define SONY_IRK_TVLEVELUP          ((SonyIRKey)0x17)
#define SONY_IRK_TVERASE            ((SonyIRKey)0x4F)
#define SONY_IRK_TVADD              ((SonyIRKey)0x0F)
#define SONY_IRK_TVAUTOPROGRAM      ((SonyIRKey)0x6B)
#define SONY_IRK_TVCABLE            ((SonyIRKey)0x39)
#define SONY_IRK_TVTVVIDEO          ((SonyIRKey)0x52)
#define SONY_IRK_TVMTS              ((SonyIRKey)0x74)
#define SONY_IRK_TVDISPLAY          ((SonyIRKey)0x2E)
#define SONY_IRK_TVJUMP             ((SonyIRKey)0x6E)
#define SONY_IRK_TVPICTUREUP        ((SonyIRKey)0x0C)
#define SONY_IRK_TVPICTUREDOWN      ((SonyIRKey)0x4C)
#define SONY_IRK_TVVOLUMEUP         ((SonyIRKey)0x24)
#define SONY_IRK_TVVOLUMEDOWN       ((SonyIRKey)0x64)

/* SONY KEY CODES UNIQUE TO SONY CD Players */
#define SONY_IRK_CDCONTINUE         ((SonyIRKey)0x5C)
#define SONY_IRK_CDSHUFFLE          ((SonyIRKey)0x56)
#define SONY_IRK_CDPROGRAM          ((SonyIRKey)0x7C)
#define SONY_IRK_CDMEGACONTROL      ((SonyIRKey)0x7B)
#define SONY_IRK_CDMUSICSCAN        ((SonyIRKey)0x1E)
#define SONY_IRK_CDHIGHLIGHT        ((SonyIRKey)0x7E)
#define SONY_IRK_CDDISC             ((SonyIRKey)0x29)
#define SONY_IRK_CDTIMETEXT         ((SonyIRKey)0x0A)
#define SONY_IRK_CDFADER            ((SonyIRKey)0x7D)
#define SONY_IRK_CDGREATERTHAN10    ((SonyIRKey)0x72)
#define SONY_IRK_CD10               ((SonyIRKey)0x02)
#define SONY_IRK_CDREPEAT           ((SonyIRKey)0x1A)
#define SONY_IRK_CDCHECK            ((SonyIRKey)0x58)
#define SONY_IRK_CDCLEAR            ((SonyIRKey)0x78)
#define SONY_IRK_CDMEMO             ((SonyIRKey)0x4B)
#define SONY_IRK_CDPLAY             ((SonyIRKey)0x26)
#define SONY_IRK_CDPAUSE            ((SonyIRKey)0x4E)
#define SONY_IRK_CDSTOP             ((SonyIRKey)0x0E)
#define SONY_IRK_CDPREV             ((SonyIRKey)0x06)
#define SONY_IRK_CDNEXT             ((SonyIRKey)0x46)
#define SONY_IRK_CDREW              ((SonyIRKey)0x66)
#define SONY_IRK_CDFF               ((SonyIRKey)0x16)
#define SONY_IRK_CDDISCMINUS        ((SonyIRKey)0x5E)
#define SONY_IRK_CDDISCPLUS         ((SonyIRKey)0x3E)
#define SONY_IRK_CDLINEOUTMINUS     ((SonyIRKey)0x64)
#define SONY_IRK_CDLINEOUTPLUS      ((SonyIRKey)0x24)

/* SONY KEY CODES UNIQUE TO SONY VCRs */
#define SONY_IRK_VCRTIMERREC        ((SonyIRKey)0x53)
#define SONY_IRK_VCRTVVCR           ((SonyIRKey)0x2A)
#define SONY_IRK_VCREDITMONITOR     ((SonyIRKey)0x55)
#define SONY_IRK_VCRTIMERONSCREEN   ((SonyIRKey)0x1D)
#define SONY_IRK_VCRINDEX           ((SonyIRKey)0x65)
#define SONY_IRK_VCRDATASCREEN      ((SonyIRKey)0x2D)
#define SONY_IRK_VCRAUDIOMONITOR    ((SonyIRKey)0x74)
#define SONY_IRK_VCRCOUNTERRESET    ((SonyIRKey)0x31)
#define SONY_IRK_VCRSHUTTLEEDITBACK ((SonyIRKey)0x69)
#define SONY_IRK_VCRSHUTTLEEDITFWD  ((SonyIRKey)0x29)
#define SONY_IRK_VCRPAUSE           ((SonyIRKey)0x4C)
#define SONY_IRK_VCRRECORD          ((SonyIRKey)0x5C)
#define SONY_IRK_VCRAUDIOINSERT     ((SonyIRKey)0x0B)
#define SONY_IRK_VCRVIDEOINSERT     ((SonyIRKey)0x4B)
#define SONY_IRK_VCRHIGHSPEEDREW    ((SonyIRKey)0x5F)
#define SONY_IRK_VCRSEARCHBACK      ((SonyIRKey)0x0A)
#define SONY_IRK_VCRSEARCHFORWARD   ((SonyIRKey)0x4A)
#define SONY_IRK_VCRREWIND          ((SonyIRKey)0x6C)
#define SONY_IRK_VCRFASTFORWARD     ((SonyIRKey)0x1C)
#define SONY_IRK_VCRPLAY            ((SonyIRKey)0x2C)
#define SONY_IRK_VCRSTOP            ((SonyIRKey)0x0C)
#define SONY_IRK_VCRMENU            ((SonyIRKey)0x59)
#define SONY_IRK_VCRNORTH           ((SonyIRKey)0x21)
#define SONY_IRK_VCRSOUTH           ((SonyIRKey)0x61)
#define SONY_IRK_VCRWEST            ((SonyIRKey)0x23)
#define SONY_IRK_VCREAST            ((SonyIRKey)0x43)
#define SONY_IRK_VCREXECUTE         ((SonyIRKey)0x45)
#define SONY_IRK_VCRFUNCTIONMEMORY  ((SonyIRKey)0x01)
#define SONY_IRK_VCRTVSCAN          ((SonyIRKey)0x17)
#define SONY_IRK_VCRPIP             ((SonyIRKey)0x77)
#define SONY_IRK_VCRSHIFT           ((SonyIRKey)0x7B)
#define SONY_IRK_VCRDIGITALOFF      ((SonyIRKey)0x3B)
#define SONY_IRK_VCRFRAMEBACK       ((SonyIRKey)0x06)
#define SONY_IRK_VCRFRAMESTILL      ((SonyIRKey)0x02)
#define SONY_IRK_VCRFRAMEFORWARD    ((SonyIRKey)0x46)
#define SONY_IRK_VCRTIMERCLEAR      ((SonyIRKey)0x63)
#define SONY_IRK_VCRRECORDMODE      ((SonyIRKey)0x0D)
#define SONY_IRK_VCRINPUTSELECT     ((SonyIRKey)0x79)
#define SONY_IRK_VCRSLOWMINUS       ((SonyIRKey)0x3E)
#define SONY_IRK_VCRSLOWPLUS        ((SonyIRKey)0x5E)
#define SONY_IRK_VCR2XPLAYBACK      ((SonyIRKey)0x14)
#define SONY_IRK_VCRTIMERCHECK      ((SonyIRKey)0x13)
#define SONY_IRK_VCRINDEXMARK       ((SonyIRKey)0x09)
#define SONY_IRK_VCRINDEXERASE      ((SonyIRKey)0x49)

/* SONY KEY CODES UNIQUE TO SONY LASER DISC PLAYERS */
#define SONY_IRK_LDREWIND          ((SonyIRKey)0x6C)
#define SONY_IRK_LDFASTFORWARD     ((SonyIRKey)0x1C)
#define SONY_IRK_LDPREV            ((SonyIRKey)0x56)
#define SONY_IRK_LDNEXT            ((SonyIRKey)0x16)
#define SONY_IRK_LDPAUSE           ((SonyIRKey)0x4C)
#define SONY_IRK_LDSTOP            ((SonyIRKey)0x0C)
#define SONY_IRK_LDPLAY            ((SonyIRKey)0x2C)
#define SONY_IRK_PLUS10            ((SonyIRKey)0x4E)


/******************************************************************************
*  PUBLIC INLINE UTILITY FUNCTIONS
******************************************************************************/

/******************************************************************************
*  PUBLIC FUNCTIONS
******************************************************************************/
void SonyIR_Reset();
void SonyIR_OnRealTimeInterrupt();
void SonyIR_OnTimerInputCaptureInterrupt();
void SonyIR_OnIdle();

#endif /* #ifndef _MICROSTAMP11_SONYIR_H_ */

/******************************************************************************
*   LOG
*******************************************************************************
*   07-Jan-02   dwoodward   created
*
*/
